summaryrefslogtreecommitdiff
path: root/sc
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-04-08 09:06:49 +0200
committerNoel Grandin <noel@peralex.com>2015-04-08 09:07:08 +0200
commit216fdcbdb4c17f349ffd68abd1f372bea3287fad (patch)
tree1090e07b1e79ee4980f311d2b204488b0b14b6e0 /sc
parent27e8eb73c17bedbf200091ec45c5eddf55a5d8d5 (diff)
convert RECALCMODE_ constants to scoped enum
Change-Id: Ice2e45a3db59adc34a160b4b410cc51c750835f2
Diffstat (limited to 'sc')
-rw-r--r--sc/inc/address.hxx2
-rw-r--r--sc/inc/formulacell.hxx2
-rw-r--r--sc/source/core/data/documen7.cxx2
-rw-r--r--sc/source/core/data/formulacell.cxx10
-rw-r--r--sc/source/filter/excel/excform.cxx2
-rw-r--r--sc/source/filter/lotus/lotimpop.cxx2
-rw-r--r--sc/source/filter/lotus/op.cxx4
-rw-r--r--sc/source/filter/qpro/qpro.cxx2
8 files changed, 13 insertions, 13 deletions
diff --git a/sc/inc/address.hxx b/sc/inc/address.hxx
index ecb5110af671..f6650d4e975f 100644
--- a/sc/inc/address.hxx
+++ b/sc/inc/address.hxx
@@ -840,7 +840,7 @@ inline bool ScRefAddress::operator==( const ScRefAddress& rRefAddress ) const
// Global functions
-// Special values for cells always broadcasting or listening (RECALCMODE_ALWAYS
+// Special values for cells always broadcasting or listening (ScRecalcMode::ALWAYS
// and the like).
#define BCA_BRDCST_ALWAYS ScAddress( 0, SCROW_MAX, 0 )
#define BCA_LISTEN_ALWAYS ScRange( BCA_BRDCST_ALWAYS, BCA_BRDCST_ALWAYS )
diff --git a/sc/inc/formulacell.hxx b/sc/inc/formulacell.hxx
index 7b7ed096a678..8e84e00e4898 100644
--- a/sc/inc/formulacell.hxx
+++ b/sc/inc/formulacell.hxx
@@ -346,7 +346,7 @@ public:
bool IsInChangeTrack() const { return bInChangeTrack;}
// For import filters!
- void AddRecalcMode( formula::ScRecalcMode );
+ void AddRecalcMode( ScRecalcMode );
/** For import only: set a double result. */
void SetHybridDouble( double n );
/** For import only: set a string result.
diff --git a/sc/source/core/data/documen7.cxx b/sc/source/core/data/documen7.cxx
index 36b02233752a..d89ea62aac82 100644
--- a/sc/source/core/data/documen7.cxx
+++ b/sc/source/core/data/documen7.cxx
@@ -452,7 +452,7 @@ void ScDocument::CalcFormulaTree( bool bOnlyForced, bool bProgressBar, bool bSet
while ( pCell )
{
// Interpret resets bDirty and calls Remove, also the referenced!
- // the Cell remains when RECALCMODE_ALWAYS.
+ // the Cell remains when ScRecalcMode::ALWAYS.
if ( bOnlyForced )
{
if ( pCell->GetCode()->IsRecalcModeForced() )
diff --git a/sc/source/filter/excel/excform.cxx b/sc/source/filter/excel/excform.cxx
index 20685513ab44..4e5ad522dc6d 100644
--- a/sc/source/filter/excel/excform.cxx
+++ b/sc/source/filter/excel/excform.cxx
@@ -165,7 +165,7 @@ void ImportExcel::Formula(
{
pCell = rDoc.getDoc().GetFormulaCell(aScPos);
if (pCell)
- pCell->AddRecalcMode( RECALCMODE_ONLOAD_ONCE );
+ pCell->AddRecalcMode( ScRecalcMode::ONLOAD_ONCE );
}
if (pCell)
diff --git a/sc/source/filter/lotus/lotimpop.cxx b/sc/source/filter/lotus/lotimpop.cxx
index 6c6d2ece628d..a8a3026165a4 100644
--- a/sc/source/filter/lotus/lotimpop.cxx
+++ b/sc/source/filter/lotus/lotimpop.cxx
@@ -282,7 +282,7 @@ ScFormulaCell *ImportLotus::Formulacell( sal_uInt16 n )
aConv.Convert( pErg, nRest );
ScFormulaCell* pCell = pErg ? new ScFormulaCell(pD, aAddr, *pErg) : new ScFormulaCell(pD, aAddr);
- pCell->AddRecalcMode( RECALCMODE_ONLOAD_ONCE );
+ pCell->AddRecalcMode( ScRecalcMode::ONLOAD_ONCE );
pD->EnsureTable(aAddr.Tab());
pD->SetFormulaCell(aAddr, pCell);
diff --git a/sc/source/filter/lotus/op.cxx b/sc/source/filter/lotus/op.cxx
index 69a9214815c9..bc5b6901db91 100644
--- a/sc/source/filter/lotus/op.cxx
+++ b/sc/source/filter/lotus/op.cxx
@@ -157,7 +157,7 @@ void OP_Formula(LotusContext &rContext, SvStream& r, sal_uInt16 /*n*/)
if (ValidColRow(nCol, nRow))
{
ScFormulaCell* pCell = new ScFormulaCell(rContext.pLotusRoot->pDoc, aAddress, *pErg);
- pCell->AddRecalcMode( RECALCMODE_ONLOAD_ONCE );
+ pCell->AddRecalcMode( ScRecalcMode::ONLOAD_ONCE );
rContext.pDoc->EnsureTable(0);
rContext.pDoc->SetFormulaCell(ScAddress(nCol, nRow, 0), pCell);
@@ -404,7 +404,7 @@ void OP_Formula123(LotusContext& rContext, SvStream& r, sal_uInt16 n)
if (ValidColRow(nCol, nRow) && nTab <= rContext.pDoc->GetMaxTableNumber())
{
ScFormulaCell* pCell = new ScFormulaCell(rContext.pLotusRoot->pDoc, aAddress, *pErg);
- pCell->AddRecalcMode( RECALCMODE_ONLOAD_ONCE );
+ pCell->AddRecalcMode( ScRecalcMode::ONLOAD_ONCE );
rContext.pDoc->EnsureTable(nTab);
rContext.pDoc->SetFormulaCell(ScAddress(nCol,nRow,nTab), pCell);
}
diff --git a/sc/source/filter/qpro/qpro.cxx b/sc/source/filter/qpro/qpro.cxx
index 0d8829b5fb53..7a73b2ee3bd3 100644
--- a/sc/source/filter/qpro/qpro.cxx
+++ b/sc/source/filter/qpro/qpro.cxx
@@ -115,7 +115,7 @@ FltError ScQProReader::readSheet( SCTAB nTab, ScDocument* pDoc, ScQProStyle *pSt
{
ScFormulaCell* pFormula = new ScFormulaCell(pDoc, aAddr, *pArray);
nStyle = nStyle >> 3;
- pFormula->AddRecalcMode( RECALCMODE_ONLOAD_ONCE );
+ pFormula->AddRecalcMode( ScRecalcMode::ONLOAD_ONCE );
pStyle->SetFormat( pDoc, nCol, nRow, nTab, nStyle );
pDoc->EnsureTable(nTab);
pDoc->SetFormulaCell(ScAddress(nCol,nRow,nTab), pFormula);
diff --git a/sc/source/core/data/formulacell.cxx b/sc/source/core/data/formulacell.cxx
index 3ba5fc240e49..3e8e160bf9bd 100644
--- a/sc/source/core/data/formulacell.cxx
+++ b/sc/source/core/data/formulacell.cxx
@@ -1397,7 +1397,7 @@ void ScFormulaCell::CalcAfterLoad( sc::CompileFormulaContext& rCxt, bool bStartL
}
// Do the cells need to be calculated? After Load cells can contain an error code, and then start
// the listener and Recalculate (if needed) if not RECALCMODE_NORMAL
if( !bNewCompiled || !pCode->GetCodeError() )
{
if (bStartListening)
@@ -2101,7 +2101,7 @@ void ScFormulaCell::Notify( const SfxHint& rHint )
}
// Don't remove from FormulaTree to put in FormulaTrack to
// put in FormulaTree again and again, only if necessary.
// Any other means except RECALCMODE_ALWAYS by which a cell could
// be in FormulaTree if it would notify other cells through
// FormulaTrack which weren't in FormulaTrack/FormulaTree before?!?
// Yes. The new TableOpDirty made it necessary to have a
@@ -2255,11 +2255,11 @@ void ScFormulaCell::SetResultError( sal_uInt16 n )
void ScFormulaCell::AddRecalcMode( ScRecalcMode nBits )
{
- if ( (nBits & RECALCMODE_EMASK) != RECALCMODE_NORMAL )
+ if ( (nBits & RECALCMODE_EMASK) != ScRecalcMode::NORMAL )
SetDirtyVar();
- if ( nBits & RECALCMODE_ONLOAD_ONCE )
+ if ( nBits & ScRecalcMode::ONLOAD_ONCE )
{ // OnLoadOnce nur zum Dirty setzen nach Filter-Import
- nBits = (nBits & ~RECALCMODE_EMASK) | RECALCMODE_NORMAL;
+ nBits = (nBits & ~RECALCMODE_EMASK) | ScRecalcMode::NORMAL;
}
pCode->AddRecalcMode( nBits );
}
@@ -1397,7 +1397,7 @@ void ScFormulaCell::CalcAfterLoad( sc::CompileFormulaContext& rCxt, bool bStartL
}
// Do the cells need to be calculated? After Load cells can contain an error code, and then start
- // the listener and Recalculate (if needed) if not RECALCMODE_NORMAL
+ // the listener and Recalculate (if needed) if not ScRecalcMode::NORMAL
if( !bNewCompiled || !pCode->GetCodeError() )
{
@@ -2101,7 +2101,7 @@ void ScFormulaCell::Notify( const SfxHint& rHint )
// Don't remove from FormulaTree to put in FormulaTrack to
// put in FormulaTree again and again, only if necessary.
- // Any other means except RECALCMODE_ALWAYS by which a cell could
+ // Any other means except ScRecalcMode::ALWAYS by which a cell could
// be in FormulaTree if it would notify other cells through
// FormulaTrack which weren't in FormulaTrack/FormulaTree before?!?